PacketParser class

Constructors

PacketParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodePacket(dynamic encodedPacket, dynamic binaryType) → dynamic
decodePayload(dynamic encodedPayload, dynamic binaryType) → dynamic
Decodes data when a payload is maybe expected. Possible binary contents are decoded from their base64 representation
encodePacket(Map packet, {required bool supportsBinary, required dynamic callback(dynamic _), bool fromClient = false}) String?
encodePayload(List packets, {required dynamic callback(dynamic _)}) → dynamic
map(List ary, dynamic each(dynamic _, dynamic callback(dynamic _)), dynamic done(dynamic _)) → dynamic
Async array map using after