Methods
-
clearListeners()
→ void
-
This function unbinds all the handlers for all the events.
inherited
-
close([dynamic closeFn()?])
→ void
-
-
discard()
→ void
-
-
doClose([dynamic callback()?])
→ void
-
-
emit(String event, [dynamic data])
→ void
-
This function triggers all the handlers currently listening
to
event and passes them data.
inherited
-
hasListeners(String event)
→ bool
-
Returns whether the event has registered.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
off(String event, [Function? handler])
→ void
-
This function attempts to unbind the
handler from the event
inherited
-
on<T>(String event, EventHandler<T> handler)
→ void
-
This function binds the
handler as a listener to the event
inherited
-
once<T>(String event, EventHandler<T> handler)
→ void
-
This function binds the
handler as a listener to the first
occurrence of the event. When handler is called once,
it is removed.
inherited
-
onClose()
→ void
-
-
onData(dynamic data)
→ void
-
-
onError(dynamic msg, [dynamic desc])
→ void
-
-
onPacket(Map packet)
→ void
-
-
onRequest(SocketConnect connect)
→ void
-
-
send(List<Map> data)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited